@@ -128,7 +128,7 @@ def Guppy_Run_and_Combine_Output( path_folder_nanopore_sequencing_data = None, f
         
         ''' combine fastq.gz output files of guppy_basecaller output '''
         if flag_barcoding_was_used :
-            for path_folder_barcode in glob.glob( path_folder_guppy_output + '*/*/' ) :
+            for path_folder_barcode in glob.glob( path_folder_guppy_output + 'pass/*/' ) + glob.glob( path_folder_guppy_output + 'fail/*/' ) :
                 name_barcode = path_folder_barcode.rsplit( '/', 2 )[ 1 ] # retrieve barcode name from the path
                 path_file_fastq_gz = f"{path_folder_guppy_output}{name_barcode}.fastq.gz"
                 OS_FILE_Combine_Files_in_order( list( glob.glob( f"{path_folder_guppy_output}*/{name_barcode}/*" + '*fastq.gz' ) ), path_file_fastq_gz, flag_bgzip_output = False ) # combine fastq files
@@ -139,7 +139,7 @@ def Guppy_Run_and_Combine_Output( path_folder_nanopore_sequencing_data = None, f
             set_path_file_fastq_gz.add( path_file_fastq_gz )
     ''' copy and combine output fastq files to the output directory '''
     if path_folder_output_fastq is not None : # if output folder of fastq files was given
-        # group 'path_file_fastq_gz' based on 'name_file'
+        # group 'path_file_fastq_gz' based on 'name_file' 
         
         dict_name_file_to_dir = dict( )
         for d in set_path_file_fastq_gz :
@@ -147,6 +147,7 @@ def Guppy_Run_and_Combine_Output( path_folder_nanopore_sequencing_data = None, f
             if name_file not in dict_name_file_to_dir :
                 dict_name_file_to_dir[ name_file ] = [ ]
             dict_name_file_to_dir[ name_file ].append( d )
+        
         for name_file in dict_name_file_to_dir : # for each output 'name_file' (barcodes), combine and copy the file to the given output folder
             OS_FILE_Combine_Files_in_order( dict_name_file_to_dir[ name_file ], f"{path_folder_output_fastq}{name_file}", flag_bgzip_output = False ) # combine fastq files
             
